@@ -1,6 +1,7 @@
 import pandas as pd
 from . import utils
 from . import stats
+from . import plots
 from tabulate import tabulate
 
 def drawdown_details(drawdown):
@@ -85,13 +86,13 @@ def to_num (input, dec=1):
     dec = '{:,.1f}'
   return input.map(dec.format)
 
-def metrics (dr, bench, rf, periods=252):
+def metrics(dr, bench, rf, periods=252):
   rfd = rf['dR'].rename('DI')
   rfy = rf['yR'].rename('DI')
   frames = [dr, bench]
   df = pd.concat(frames, axis=1)
   dd = utils.to_drawdown_series(df)
-  dd_details = reports.drawdown_details(dd)
+  dd_details = drawdown_details(dd)
   display = pd.DataFrame()
   print('[Analysis info]')
   date_start = dr.index.strftime('%Y-%m-%d')[0]
@@ -258,4 +259,93 @@ def metrics (dr, bench, rf, periods=252):
     print('%s : 5 Worst Drawdowns' % c)
     print(tabulate(dd_details[c].sort_values(by='max drawdown', ascending=True)[:5], headers="keys", tablefmt='simple', showindex=False))
     print('\n')
-  return None
\ No newline at end of file
+  return None
+
+def plots(returns, benchmark, rf, grayscale=False, figsize=(8, 5), periods=252):
+  rfd=rf['dR']
+  rfy=rf['yR']
+  plots.plt_returns(returns, benchmark, rfd,
+              grayscale=grayscale,
+              figsize=(figsize[0], figsize[0]*.6),
+              show=True,
+              ylabel=False)
+  plots.plt_log_returns(returns, benchmark, rfd,
+              grayscale=grayscale,
+              figsize=(figsize[0], figsize[0]*.5),
+              show=True,
+              ylabel=False)
+  plots.plt_volmatch_returns(returns, benchmark, rfd,
+              grayscale=grayscale,
+              figsize=(figsize[0], figsize[0]*.5),
+              show=True,
+              ylabel=False)
+  plots.plt_yearly_returns(returns, benchmark, rfd,
+              grayscale=grayscale,
+              figsize=(figsize[0], figsize[0]*.5),
+              show=True,
+              ylabel=False)
+  
+  plots.plt_histogram(returns,
+                grayscale=grayscale,
+                figsize=(figsize[0], figsize[0]*.5),
+                show=True,
+                ylabel=False)
+  
+  plots.plt_daily_returns(returns,
+                    grayscale=grayscale,
+                    figsize=(figsize[0], figsize[0]*.3),
+                    show=True,
+                    ylabel=False)
+  
+  plots.plt_rolling_beta(returns, benchmark,
+                   grayscale=grayscale,
+                   window1=int(periods/2),
+                   window2=periods,
+                   figsize=(figsize[0], figsize[0]*.3),
+                   show=True,
+                   ylabel=False)
+  
+  plots.plt_rolling_volatility(returns, benchmark,
+                         grayscale=grayscale,
+                         figsize=(figsize[0], figsize[0]*.3),
+                         show=True,
+                         ylabel=False,
+                         period=int(periods/2))
+  
+  plots.plt_rolling_sharpe(returns, benchmark, rfy,
+                     grayscale=grayscale,
+                     figsize=(figsize[0], figsize[0]*.3),
+                     show=True,
+                     ylabel=False,
+                     period=int(periods/2))
+
+  plots.plt_rolling_sortino(returns, benchmark, rfy,
+                      grayscale=grayscale,
+                      figsize=(figsize[0], figsize[0]*.3),
+                      show=True,
+                      ylabel=False,
+                      period=int(periods/2))
+  
+  plots.plt_drawdowns_periods(returns, periods=5,
+                        grayscale=grayscale,
+                        figsize=(figsize[0], figsize[0]*.5),
+                        show=True,
+                        ylabel=False)
+
+  plots.plt_drawdown(returns,
+               grayscale=grayscale,
+               figsize=(figsize[0], figsize[0]*.4),
+               show=True,
+               ylabel=False)
+
+  plots.plt_monthly_heatmap(returns,
+                      grayscale=grayscale,
+                      figsize=(figsize[0], figsize[0]*.5),
+                      show=True,
+                      ylabel=False)
+
+  plots.plt_distribution(returns,
+                   grayscale=grayscale,
+                   figsize=(figsize[0], figsize[0]*.5),
+                   show=True, 
+                   ylabel=False)
